@@ -8,19 +8,16 @@ data that was previously present in the MMIF file.
 from datetime import datetime
 from typing import Dict, Union, Optional, Generator, List, cast
 
-import dateutil.parser
-from pyrsistent import pmap, pvector
-
 from mmif.vocabulary import ThingTypesBase
 from .annotation import Annotation, Document
-from .model import FreezableMmifObject, FreezableDataList, FreezableDataDict, MmifObject
+from .model import MmifObject, DataList, DataDict
 
 __all__ = ['View', 'ViewMetadata', 'Contain']
 
 from .. import DocumentTypes
 
 
-class View(FreezableMmifObject):
+class View(MmifObject):
     """
     View object that represents a single view in a MMIF file.
 
@@ -33,17 +30,17 @@ class View(FreezableMmifObject):
     :param view_obj: the JSON data that defines the view
     """
 
-    def __init__(self, view_obj: Union[bytes, str, dict] = None) -> None:
+    def __init__(self, view_obj: Optional[Union[bytes, str, dict]] = None) -> None:
         self._id_counts = {}
         self.id: str = ''
         self.metadata: ViewMetadata = ViewMetadata()
         self.annotations: AnnotationsList = AnnotationsList()
         self.disallow_additional_properties()
-        self._attribute_classes = pmap({
+        self._attribute_classes = {
             'metadata': ViewMetadata,
             'annotations': AnnotationsList
-        })
-        self._required_attributes = pvector(["id", "metadata", "annotations"])
+        }
+        self._required_attributes = ["id", "metadata", "annotations"]
         super().__init__(view_obj)
         for item in self.annotations:
             if isinstance(item, Document):
@@ -96,7 +93,7 @@ class View(FreezableMmifObject):
         new_annotation.at_type = at_type
         self._set_id(new_annotation, aid)
         for propk, propv in properties.items():
-            new_annotation.add_property(propk, propk)
+            new_annotation.add_property(propk, propv)
         return self.add_annotation(new_annotation, overwrite)
 
     def add_annotation(self, annotation: 'Annotation', overwrite=False) -> 'Annotation':
@@ -115,8 +112,6 @@ class View(FreezableMmifObject):
                           in the view
         :return: the same Annotation object passed in as ``annotation``
         """
-        if self.is_frozen():
-            raise TypeError("MMIF object is frozen")
         self.annotations.append(annotation, overwrite)
         self.new_contain(annotation.at_type)
         return annotation
@@ -166,7 +161,7 @@ class View(FreezableMmifObject):
         document.parent = self.id
         return self.add_annotation(document, overwrite)
 
-    def get_annotations(self, at_type: Union[str, ThingTypesBase] = None, 
+    def get_annotations(self, at_type: Optional[Union[str, ThingTypesBase]] = None, 
                         **properties) -> Generator[Annotation, None, None]:
         """
         Look for certain annotations in this view, specified by parameters
@@ -231,25 +226,26 @@ class View(FreezableMmifObject):
         self.annotations.empty()
 
 
-class ViewMetadata(FreezableMmifObject):
+class ViewMetadata(MmifObject):
     """
     ViewMetadata object that represents the ``metadata`` object within a MMIF view.
 
     :param viewmetadata_obj: the JSON data that defines the metadata
     """
 
-    def __init__(self, viewmetadata_obj: Union[bytes, str, dict] = None) -> None:
+    def __init__(self, viewmetadata_obj: Optional[Union[bytes, str, dict]] = None) -> None:
         self.document: str = ''
         self.timestamp: Optional[datetime] = None
         self.app: str = ''
         self.contains: ContainsDict = ContainsDict()
         self.parameters: dict = {}
         self.error: Union[dict, ErrorDict] = {}
-        self._required_attributes = pvector(["app"])
-        self._attribute_classes = pmap(
-            {'error': ErrorDict, 
-             'contains': ContainsDict}
-        )
+        self.warnings: List[str] = []
+        self._required_attributes = ["app"]
+        self._attribute_classes = {
+            'error': ErrorDict,
+            'contains': ContainsDict
+        }
         # in theory, either `contains` or `error` should appear in a `view`
         # but with current implementation, there's no easy way to set a condition 
         # for `oneOf` requirement 
@@ -287,33 +283,40 @@ class ViewMetadata(FreezableMmifObject):
     def set_error(self, message: str, stack_trace: str):
         self.error = ErrorDict({"message": message, "stackTrace": stack_trace})
         self.contains.empty()
+    
+    def add_warnings(self, *warnings: Warning):
+        for warning in warnings:
+            self.warnings.append(f'{warning.__class__.__name__}: {" - ".join(warning.args)}')
+
+    def emtpy_warnings(self):
+        self.warnings = []
 
 
-class ErrorDict(FreezableMmifObject):
+class ErrorDict(MmifObject):
     """
     Error object that stores information about error occurred during processing. 
     """
-    def __init__(self, error_obj: Union[bytes, str, dict] = None) -> None:
+    def __init__(self, error_obj: Optional[Union[bytes, str, dict]] = None) -> None:
         self.message: str = ''
         self.stackTrace: str = ''
         super().__init__(error_obj)
         
 
-class Contain(FreezableMmifObject):
+class Contain(MmifObject):
     """
     Contain object that represents the metadata of a single
     annotation type in the ``contains`` metadata of a MMIF view.
     """
 
 
-class AnnotationsList(FreezableDataList[Union[Annotation, Document]]):
+class AnnotationsList(DataList[Union[Annotation, Document]]):
     """
     AnnotationsList object that implements :class:`mmif.serialize.model.DataList`
     for :class:`mmif.serialize.annotation.Annotation`.
     """
     _items: Dict[str, Union[Annotation, Document]]
 
-    def _deserialize(self, input_list: list) -> None:
+    def _deserialize(self, input_list: list) -> None:  # pytype: disable=signature-mismatch
         """
         Extends base ``_deserialize`` method to initialize ``items`` as a dict from
         annotation IDs to :class:`mmif.serialize.annotation.Annotation` objects.
@@ -344,7 +347,7 @@ class AnnotationsList(FreezableDataList[Union[Annotation, Document]]):
         super()._append_with_key(value.id, value, overwrite)
 
 
-class ContainsDict(FreezableDataDict[ThingTypesBase, Contain]):
+class ContainsDict(DataDict[ThingTypesBase, Contain]):
 
     def _deserialize(self, input_dict: dict) -> None:
         self._items = {ThingTypesBase.from_str(key): Contain(value) for key, value in input_dict.items()}
